==> phplist-2.10.5.tgz: lists/admin/lan/zh-tw/importadmin.php <==
<?php
$lan = array (
  'File is either to large or does not exist.' => '檔案太大或不存在',
  'No file was specified.' => '沒有指定檔案',
  'Some characters that are not valid have been found. These might be delimiters. Please check the file and select the right delimiter. Character found:' => '發現部分字元錯誤，可能資料中包含了分隔字元，請檢查檔案後選擇正確的分隔字元。找到的字元：',
  'Name cannot be empty' => '名稱不能空白',
  'Name is not unique enough' => '名稱必須唯一',
  'Cannot find the email in the header' => '從頁首找不到 email',
  'Cannot find the password in the header' => '從頁首找不到密碼',
  'Cannot find the loginname in the header' => '從頁首找不到帳號',
  'Record has no email' => '沒有email',
  'Invalid Email' => '錯誤的email',
  'Record has more values than header indicated, this may cause trouble' => '資料有超過頁首定義的數值，這也許會造成錯誤',
  'password' => '密碼',
  'loginname' => '帳號',
  'Empty loginname, using email:' => '空白的帳號，使用 email：',
  'Value' => '數值',
  'added to attribute' => '新增到欄位',
  'new email was' => '新 email 是',
  'new emails were' => '新 email 是',
  'email was' => 'email 是',
  'emails were' => 'email 是',
  'All the emails already exist in the database' => '所有的 emails 都已經在資料庫中',
  'succesfully imported to the database and added to the system.' => '成功匯入到資料庫並且新增到系統中',
  'Import some more emails' => '匯入更多 email',
  'No default permissions have been defined, please create default permissions first, by creating one dummy admin and assigning the default permissions to this admin' => '沒有定義預設權限，請先建立一個預設權限，並且指定預設的權限給這個管理者',
  'importadmininfo' => '您上傳的檔案必須包含您希望新增的管理者資訊，標題列需要包含欄位如下：<b>email</b>、<b>帳號</b>、<b>密碼</b>，其他的欄位會被新增為管理者欄位。
 <b>注意</b>：檔案必須是純文字格式，而非 Word 之類的文件
  ',
  'File containing emails' => '檔案包含 email',
  'Field Delimiter' => '欄位分隔字元',
  'Record Delimiter' => '資料分隔字元',
  'importadmintestinfo' => '如果您選擇 "測試輸出"，您將會看到系統解析出來的 email 清單，而不會立刻新增到資料庫中。這個功能可以協助您確認檔案格式，所以它只會擷取前五十筆資料。',
  'Test output' => '測試輸出',
  'Check this box to create a list for each administrator, named after their loginname' => '勾選這個項目來為每個管理者建立電子報，會以他們的帳號作為名稱',
  'Do Import' => '匯入',
  'default is TAB' => '遇設是 TAB',
  'default is line break' => '預設是段落',
  'testoutputinfo' => '測試輸出：<br>一行應該只有一個 email。<br>如果輸出正常，可以 <a href="javascript:history.go(-1)">回上頁</a> 來正式送出<br><br>',
  'List for' => '電子報',
  'login' => '帳號',

);
?>

==> phplist-2.10.14p1.tgz: lists/admin/lan/zh-tw/importadmin.php <==
<?php
$lan = array (
  'File is either to large or does not exist.' => '檔案太大或不存在',
  'No file was specified.' => '沒有指定檔案',
  'Some characters that are not valid have been found. These might be delimiters. Please check the file and select the right delimiter. Character found:' => '發現部分字元錯誤，可能資料中包含了分隔字元，請檢查檔案後選擇正確的分隔字元。找到的字元：',
  'Name cannot be empty' => '名稱不能空白',
  'Name is not unique enough' => '名稱必須唯一',
  'Cannot find the email in the header' => '從頁首找不到 email',
  'Cannot find the password in the header' => '從頁首找不到密碼',
  'Cannot find the loginname in the header' => '從頁首找不到帳號',
  'Record has no email' => '沒有email',
  'Invalid Email' => '錯誤的email',
  'Record has more values than header indicated, this may cause trouble' => '資料有超過頁首定義的數值，這也許會造成錯誤',
  'password' => '密碼',
  'loginname' => '帳號',
  'Empty loginname, using email:' => '空白的帳號，使用 email：',
  'Value' => '數值',
  'added to attribute' => '新增到欄位',
  'new email was' => '新 email 是',
  'new emails were' => '新 email 是',
  'email was' => 'email 是',
  'emails were' => 'email 是',
  'All the emails already exist in the database' => '所有的 emails 都已經在資料庫中',
  'succesfully imported to the database and added to the system.' => '成功匯入到資料庫並且新增到系統中',
  'Import some more emails' => '匯入更多 email',
  'No default permissions have been defined, please create default permissions first, by creating one dummy admin and assigning the default permissions to this admin' => '沒有定義預設權限，請先建立一個預設權限，並且指定預設的權限給這個管理者',
  'importadmininfo' => '您上傳的檔案必須包含您希望新增的管理者資訊，標題列需要包含欄位如下：<b>email</b>、<b>帳號</b>、<b>密碼</b>，其他的欄位會被新增為管理者欄位。
 <b>注意</b>：檔案必須是純文字格式，而非 Word 之類的文件
  ',
  'File containing emails' => '檔案包含 email',
  'Field Delimiter' => '欄位分隔字元',
  'Record Delimiter' => '資料分隔字元',
  'importadmintestinfo' => '如果您選擇 "測試輸出"，您將會看到系統解析出來的 email 清單，而不會立刻新增到資料庫中。這個功能可以協助您確認檔案格式，所以它只會擷取前五十筆資料。',
  'Test output' => '測試輸出',
  'Check this box to create a list for each administrator, named after their loginname' => '勾選這個項目來為每個管理者建立電子報，會以他們的帳號作為名稱',
  'Do Import' => '匯入',
  'default is TAB' => '遇設是 TAB',
  'default is line break' => '預設是段落',
  'testoutputinfo' => '測試輸出：<br/>一行應該只有一個 email。<br/>如果輸出正常，可以 <a href="javascript:history.go(-1)">回上頁</a> 來正式送出<br/><br/>',
  'List for' => '電子報',
  'login' => '帳號',

);
?>
